{% extends 'plans/base.html' %}
{% load i18n %}


{% block body %}
    <div class="row">
        <div class="col-sm-6">
          <form action="{{ request.get_full_path }}" method="post" class="form">
                <legend>{% trans "Provide billing data" %}</legend>
                {% csrf_token %}
                {{ form.as_p }}
                <a class="btn btn-danger" href="{% url 'billing_info_delete' %}">Delete</a>
                <button type="submit" class="btn btn-primary">
                    Save
                </button>
            </form>
        </div>
    </div>
{% endblock %}
