<!DOCTYPE html>
<html lang="en">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    {% block extra_js %}
    {% endblock %}
</head>
<body>
    <h1>django-plans</h1>
    {% include "plans/expiration_messages.html" %}

    {% block body %}
    {% endblock %}
</body>
</html>
