# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('plans', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userplan',
            name='plan',
            field=models.ForeignKey(verbose_name='plan', to='plans.Plan', null=True),
        ),
    ]
